@@ -1,4 +1,6 @@
 RGEOSMiscFunc = function(spgeom, byid, func) {
+    if (!is.na(is.projected(spgeom)) && !is.projected(spgeom))
+     warning("Spatial object is not projected; GEOS expects planar coordinates")
     byid = as.logical(byid)
     if (is.na(byid)) stop("Invalid value for byid, must be logical")
     
@@ -18,6 +20,11 @@ gLength = function(spgeom, byid=FALSE) {
 
 
 RGEOSDistanceFunc = function(spgeom1, spgeom2, byid, func, densifyFrac = 1) {
+    if (!is.na(is.projected(spgeom1)) && !is.projected(spgeom1))
+     warning("Spatial object 1 is not projected; GEOS expects planar coordinates")
+    if (!is.null(spgeom2) && !is.na(is.projected(spgeom2)) && 
+        !is.projected(spgeom2))
+     warning("Spatial object 2 is not projected; GEOS expects planar coordinates")
     byid = as.logical(byid)
     if (any(is.na(byid)) ) stop("Invalid value for byid, must be logical")
 
@@ -96,4 +103,4 @@ RGEOSisWithinDistance = function(spgeom1, spgeom2=NULL, dist, byid=FALSE) {
 RGEOSHausdorffDistance = function(spgeom1, spgeom2=NULL, byid=FALSE) {
     .Deprecated("gDistance")
     return( gDistance(spgeom1, spgeom2, byid, TRUE) )
-}
\ No newline at end of file
+}
