@@ -92,7 +92,7 @@ gLineMerge = function(spgeom, byid=FALSE, id = NULL) {
     return( TopologyFunc(spgeom,id,byid,"rgeos_linemerge") ) 
 }
 
-gUnionCascaded = function(spgeom, id = NULL, bound = 1000L) {
+gUnionCascaded = function(spgeom, id = NULL) {
     
     if (!inherits(spgeom,"SpatialPolygons"))
         stop("Invalid geometry, may only be applied to polygons")
@@ -101,18 +101,12 @@ gUnionCascaded = function(spgeom, id = NULL, bound = 1000L) {
     if (is.null(id))
         id = rep("1",length(row.names(spgeom)))
 
-    if (any(is.na(id))) stop("No NAs permitted in id")
+#    if (any(is.na(id))) stop("No NAs permitted in id")
 
     if (get_do_poly_check()) spgeom <- createSPComment(spgeom)
 
     ids <- split(1:length(id), id)
     sl <- sapply(ids, length)
-    if (any(sl > bound)) {
-        stop(paste("Too many polygons in group to dissolve:",
-            paste(sl, collapse=","), "greater than", bound,
-            "- see help page", ifelse(version_GEOS0() < "3.3.0", "",
-            "- consider using gUnaryUnion instead")))
-    }
     out <- vector(mode="list", length=length(ids))
     for (i in seq(along=ids)) {
         out[[i]] <- TopologyFunc(groupID(spgeom[ids[[i]]], id[ids[[i]]]),
@@ -134,7 +128,7 @@ gUnaryUnion = function(spgeom, id = NULL) {
     if (is.null(id))
         id = rep("1",length(row.names(spgeom)))
 
-    if (any(is.na(id))) stop("No NAs permitted in id")
+#    if (any(is.na(id))) stop("No NAs permitted in id")
 
     if (get_do_poly_check()) spgeom <- createSPComment(spgeom)
 
